const express = require('express');
const app = express();
const arg = process.argv;
const fs = require('fs');
const path = require('path');
const https = require('https');
const multer = require('multer');
const {conf} = require('../plug-in/fk2Path');
const confs = require(conf);
const port = arg[3]&&arg[3]>0?arg[3]:confs.workPort;
app.use(express.json()); //  application/json
app.disable('x-powered-by');//去除x-powered-by响应字段
// application/x-www-form-urlencoded
app.use(express.urlencoded({ extended: true })); 
// 根据项目的路径导入生成的证书文件
const key = fs.readFileSync(path.join(__dirname,'./key/ssl.key')).toString()
const cert = fs.readFileSync(path.join(__dirname,'./key/ssl.pem')).toString()
const {decrypt} =require('../plug-in/key')
//.any()上传任何文件 .array("files")上传"files"文件
app.use(multer({ dest: "/" }).any());
const static = require('../plug-in/static');
const logs = require('../plug-in/colorLog');
const h5 = path.join(__dirname,'./h5');
// 配置静态资源路径
const route = ['','favicon.ico','assets','static','index','index.htm','index.html'];
app.all('*', async (req, res) => { 
    const {originalUrl} = req;
    let urls = originalUrl.split("?");
    const url = urls[0].split("/");
    if(url[1]==''||url[1]=='index'||url[1]=='index.htm'){
        urls[0] = '/index.html'
    }
    if(route.indexOf(url[1])>-1){
        // 静态资源
        static(h5+urls[0].replaceAll('/','\\'),res)
    }else{
        // api路径
        const obj = require('../plug-in/express')(req);
        try {
            const {main} = require('./api'+urls[0]);
            res.json(await main(obj))
        } catch (err) {
            res.json({
                code:0,
                msg:err.code||'An unknown error!'
            })
        }
    }
})
const server = https.createServer({key:decrypt(key),cert:decrypt(cert)}, app);
server.listen(port);
server.on('listening',()=>{
    // 监听成功
    logs.g(`HTTPS Server is running on: https://${confs.workHost}:${port}`)
    logs.close()
    if(confs.workOpen==1){
        const c = require('child_process');
        c.exec(`start https://${confs.workHost}:`+port);
    }
})
server.on('error',()=>{
    // 监听失败
    logs.r('Port '+port+' is already used!')
    logs.r('Please reset a port!')
    logs.r('Command: fk2 work <port>')
    logs.close()
    process.exit();
})
